@@ -60,7 +60,7 @@ pub fn derive_variant_names(input: proc_macro::TokenStream) -> proc_macro::Token
 
     let names_struct_fields = variants.iter().map(|ident| {
         quote! {
-            #ident: &'static str
+            pub #ident: &'static str
         }
     });
 
